@@ -1,5 +1,6 @@
 from decimal import Decimal
 from typing import Optional
+from hashlib import md5
 
 from pydantic import BaseModel
 
@@ -140,9 +141,12 @@ class Person(IngestedDataType):
         country = pdl_input.get('location_country')
         job_start_date = pdl_input.get('job_start_date')
         job_last_updated = pdl_input.get('job_last_updated')
+        linkedin_url = pdl_input.get('linkedin_url')
+        linkedin_url = ("https://www." + linkedin_url) if not linkedin_url.startswith("https://www.") else linkedin_url
 
         return Person(
-            id=pdl_id,
+            # normalize string for id - empty spaces and leading and trailing /
+            id=md5(linkedin_url.replace(" ", "").strip("/").encode()).hexdigest(),
             source=Source.PDL,
             version=0,
             created_at=get_current_datetime_aws_format(),
@@ -156,7 +160,7 @@ class Person(IngestedDataType):
             email=pdl_input.get('work_email'),
             personal_emails=pdl_input.get('personal_emails'),
             phone_numbers=pdl_input.get('phone_numbers'),
-            linkedin_url=pdl_input.get('linkedin_url'),
+            linkedin_url=linkedin_url,
             linkedin_internal_id=pdl_input.get('linkedin_id'),
             industry=pdl_input.get('industry'),
             company_id=pdl_input.get('job_company_linkedin_id'),
